@@ -3,9 +3,10 @@ package Module::Load::Util;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-06-16'; # DATE
 our $DIST = 'Module-Load-Util'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use strict 'subs', 'vars';
+use Regexp::Pattern::Perl::Module ();
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
@@ -22,7 +23,7 @@ sub load_module_with_optional_args {
         defined $opts->{caller} ? $opts->{caller} :
         caller(0);
     # check because we will use eval ""
-    $target_package =~ /\A[A-Za-z_][A-Za-z0-9_]*(::[A-Za-z0-9_]*)*\z/
+    $target_package =~ $Regexp::Pattern::Perl::Module::RE{perl_modname}{pat}
         or die "Invalid syntax in target package '$target_package'";
 
     my ($module, $args) = @_;
@@ -100,7 +101,7 @@ Module::Load::Util - Some utility routines related to module loading
 
 =head1 VERSION
 
-This document describes version 0.002 of Module::Load::Util (from Perl distribution Module-Load-Util), released on 2020-06-16.
+This document describes version 0.003 of Module::Load::Util (from Perl distribution Module-Load-Util), released on 2020-06-16.
 
 =head1 SYNOPSIS
 
@@ -238,6 +239,8 @@ L<Module::Load>
 
 L<Class::Load>
 
+L<Sah::Schema::perl::modname_with_optional_args>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
